'use client';
 
import { Box, Image, ActionIcon } from '@mantine/core';
import { IconChevronLeft, IconChevronRight } from '@tabler/icons-react';
import { useRef } from 'react';
import DICGC from '@/app/image/DICGC_image.jpg';
import objective from '@/app/image/objective.jpg';
import frontPage from '@/app/image/ib_front_page.jpg';
 
export default function CustomCarousel() {
  const scrollRef = useRef<HTMLDivElement>(null);
  const scrollBy = 300; // px per click
 
  const scrollLeft = () => {
    scrollRef.current?.scrollBy({ left: -scrollBy, behavior: 'smooth' });
  };
 
  const scrollRight = () => {
    scrollRef.current?.scrollBy({ left: scrollBy, behavior: 'smooth' });
  };
 
  const images = [DICGC, objective, frontPage];
 
  return (
    <Box style={{ position: 'relative', width: '100%', overflow: 'hidden' }}>
      {/* Scrollable container */}
      <Box
        ref={scrollRef}
        style={{
          display: 'flex',
          overflowX: 'auto',
          scrollSnapType: 'x mandatory',
          gap: '1rem',
          padding: '1rem',
          scrollBehavior: 'smooth',
        }}
      >
        {images.map((img, i) => (
          <Box
            key={i}
            style={{
              flex: '0 0 100%',
              scrollSnapAlign: 'start',
              height: '250px',
              minWidth: '100%',
              maxWidth: '100%',
              borderRadius: '8px',
              backgroundColor: '#f2f2f2',
            }}
          >
            <Image
              src={img.src}
              alt={`Slide ${i + 1}`}
              style={{
                width: '100%',
                height: '100%',
                objectFit: 'contain',
              }}
            />
          </Box>
        ))}
      </Box>
 
      {/* Left Scroll Button */}
      <ActionIcon
        variant="filled"
        color="blue"
        onClick={scrollLeft}
        style={{
          position: 'absolute',
          top: '50%',
          left: '10px',
          transform: 'translateY(-50%)',
          zIndex: 10,
        }}
      >
        <IconChevronLeft size={24} />
      </ActionIcon>
 
      {/* Right Scroll Button */}
      <ActionIcon
        variant="filled"
        color="blue"
        onClick={scrollRight}
        style={{
          position: 'absolute',
          top: '50%',
          right: '10px',
          transform: 'translateY(-50%)',
          zIndex: 10,
        }}
      >
        <IconChevronRight size={24} />
      </ActionIcon>
    </Box>
  );
}
 