"use client";

import React from 'react';
import { AppShell, Button, Input, Group, Stack, Tooltip, UnstyledButton, Text, Avatar, Title, Divider, Box, Select, Paper, Image, Switch, Flex, TextInput, Center } from '@mantine/core';
import { IconBook, IconBuildingBank, IconCurrencyRupee, IconEye, IconHome, IconLogout, IconPhoneFilled, IconSettings } from '@tabler/icons-react';
import { useRouter } from "next/navigation";
import { useEffect, useState } from "react";
import { Providers } from "../providers";
import logo from '@/app/image/logo.jpg';
import NextImage from 'next/image';

export default function Home() {
    const [authorized, SetAuthorized] = useState<boolean | null>(null);
    const router = useRouter();
    const accountData = [
        { "stAccountNo": "50078975412", "stAccountType": "SA", "stAvailableBalance": "10000.0" },
        { "stAccountNo": "50078975413", "stAccountType": "SA", "stAvailableBalance": "12000.0" },
        { "stAccountNo": "50078975414", "stAccountType": "SA", "stAvailableBalance": "14000.0" },
        { "stAccountNo": "60078975412", "stAccountType": "LN", "stAvailableBalance": "100000.0" },
        { "stAccountNo": "60078975413", "stAccountType": "LN", "stAvailableBalance": "120000.0" }
    ]
    const depositAccounts = accountData.filter(acc => acc.stAccountType === "SA");
    const [selectedDA, setSelectedDA] = useState(depositAccounts[0]?.stAccountNo || "");
    const selectedDAData = depositAccounts.find(acc => acc.stAccountNo === selectedDA);
    const loanAccounts = accountData.filter(acc => acc.stAccountType === "LN");
    const [selectedLN, setSelectedLN] = useState(loanAccounts[0]?.stAccountNo || "");
    const selectedLNData = loanAccounts.find(acc => acc.stAccountNo === selectedLN);
    const [showBalance, setShowBalance] = useState(false);

    async function handleLogout(e: React.FormEvent) {
        e.preventDefault();
        localStorage.removeItem("access_token");
        router.push("/login")
    }
    useEffect(() => {
        const token = localStorage.getItem("access_token");
        if (!token) {
            SetAuthorized(false);
            router.push("/login");
        }
        else {
            SetAuthorized(true);
        }
    }, []);

    if (authorized) {
        return (
            <Providers>
                <div
                    style={{
                        backgroundColor: "#e6ffff", width: "100%", height: '100vh',
                    }}>
                    <Box style={{
                        position: 'relative', width: '100%', height: '11%',
                        display: "flex",
                        justifyContent: "flex-start",
                        background: "linear-gradient(15deg,rgba(2, 163, 85, 1) 55%, rgba(101, 101, 184, 1) 100%)",
                    }}>
                        <Image
                            // radius="md"
                            fit="cover"
                            src={logo}
                            component={NextImage}
                            alt="ebanking"
                            style={{ width: "100%", height: "100%" }}
                        />
                        <Text
                            style={{
                                position: 'absolute',
                                top: '60%',
                                left: '80%',
                                color: 'white',
                                textShadow: '1px 1px 2px black',
                            }}
                        >
                            <IconPhoneFilled size={20} />
                            Toll Free No : 1800-180-8008
                        </Text>
                    </Box>
                    <div
                        style={{
                            flex: 1,
                            display: "flex",
                            alignItems: "left",
                            justifyContent: "right",
                        }}
                    >
                        <Group mt="md" gap="sm">
                            <Button leftSection={<IconHome />} variant="light" color="blue">Home</Button>
                            <Button leftSection={<IconBook />} variant="subtle">Accounts</Button>
                            <Button leftSection={<IconCurrencyRupee />} variant="subtle">Send Money</Button>
                            {/* <Button variant="subtle">IMPS</Button> */}
                            <Button leftSection={<IconSettings />} variant="subtle">Settings</Button>
                            <Button leftSection={<IconLogout />} variant="subtle" onClick={handleLogout}>Logout</Button>
                        </Group>
                    </div>
                    <div
                        style={{
                            flex: 1,
                            marginLeft: '20px',
                            display: "flex",
                            flexDirection: "column",
                            justifyContent: "left",
                        }}
                    >
                        <Title order={3} style={{ fontFamily: "inter", fontSize: '28px' }}>Welcome, Rajat Kumar Maharana</Title>
                        {/* &nbsp; */}
                        <Text size="xs" c="gray" style={{ fontFamily: "inter", fontSize: '15px' }}>Last logged in at 29/06/25, 05:35 PM</Text>
                    </div>
                    <Group
                        style={{ flex: 1, padding: "10px 10px 4px 10px", marginLeft: '20px', display: "flex", alignItems: "center", justifyContent: "left", height: "5vh" }}>
                        <IconEye size={20} />
                        <Text fw={700} style={{ fontFamily: "inter", fontSize: '17px' }}>Show Balance </Text>
                        <Switch size="md" onLabel="ON" offLabel="OFF" checked={showBalance}
                            onChange={(event) => setShowBalance(event.currentTarget.checked)} />
                    </Group>
                    <div style={{ flex: 1, display: "flex", alignItems: "center", justifyContent: "flex-start", marginLeft: '20px' }}>
                        <Group grow gap="xl">
                            <Paper p="md" radius="md" style={{ backgroundColor: '#c1e0f0', width: 350 }}>

                                <Group gap='xs'>
                                    <IconBuildingBank size={25} />
                                    <Text fw={700}>Deposit Account</Text>
                                    <Select
                                        // placeholder="Select A/C No"
                                        data={depositAccounts.map(acc => ({
                                            value: acc.stAccountNo,
                                            label: acc.stAccountNo
                                        }))}
                                        value={selectedDA}
                                        // @ts-ignore
                                        onChange={setSelectedDA}
                                        size="xs"
                                        styles={{
                                            input: {
                                                backgroundColor: "white",
                                                color: "black",
                                                marginLeft: 20,
                                                width: 125
                                            }
                                        }}
                                    />
                                </Group>
                                <Text c="dimmed">{Number(selectedDAData?.stAccountNo || 0)}</Text>
                                <Title order={2} mt="md">
                                    {showBalance ? `₹${Number(selectedDAData?.stAvailableBalance || 0).toLocaleString('en-IN')}` : "****"}
                                </Title>
                                <Button fullWidth mt="xs">Get Statement</Button>
                            </Paper>
                            <Paper p="md" radius="md" style={{ backgroundColor: '#c1e0f0', width: 350 }}>

                                <Group gap='xs'>
                                    <IconBuildingBank size={25} />
                                    <Text fw={700}>Loan Account</Text>
                                    <Select
                                        placeholder="Select A/C No"
                                        data={loanAccounts.map(acc => ({
                                            value: acc.stAccountNo,
                                            label: acc.stAccountNo
                                        }))}
                                        value={selectedLN}
                                        // @ts-ignore
                                        onChange={setSelectedLN}
                                        size="xs"
                                        styles={{
                                            input: {
                                                backgroundColor: "white",
                                                color: "black",
                                                marginLeft: 25,
                                                width: 125
                                            }
                                        }}
                                    />
                                </Group>
                                <Text c="dimmed">{Number(selectedLNData?.stAccountNo || 0)}</Text>
                                <Title order={2} mt="md">
                                    {showBalance ? `₹${Number(selectedLNData?.stAvailableBalance || 0).toLocaleString('en-IN')}` : "****"}
                                </Title>
                                <Button fullWidth mt="xs">Get Statement</Button>
                            </Paper>
                            <Paper p="md" radius="md" style={{ width: 300, backgroundColor: '#FFFFFF', marginLeft: '130px', border: '1px solid grey' }}>
                                <Title order={5} mb="sm">Important Links</Title>
                                {/* <Title order={5} mb="sm" style={{ textAlign: 'center' }}>Loan EMI Calculator</Title> */}
                                <Stack gap="xs">
                                    <Button variant="light" color="blue" fullWidth>Loan EMI Calculator</Button>
                                    <Button variant="light" color="blue" fullWidth>Branch Locator</Button>
                                    <Button variant="light" color="blue" fullWidth>Customer Care</Button>
                                    <Button variant="light" color="blue" fullWidth>FAQs</Button>
                                </Stack>
                                {/* <Group>
                                    <TextInput
                                        label="Loan Amount"
                                        placeholder=""
                                    />
                                    <TextInput
                                        label="Interest Rate(%)"
                                        placeholder=""
                                    />
                                    <TextInput
                                        label="Loan Tenure(Years)"
                                        placeholder=""
                                    />
                                    <Button fullWidth style={{textAlign:'center'}}>Calculate</Button>
                                </Group> */}
                            </Paper>
                        </Group>
                    </div>
                    <div
                        style={{
                            flex: 1,
                            marginTop: 0,
                            padding: "20px",
                            display: "flex",
                            // alignItems: "center",
                            justifyContent: "left",
                        }}
                    >
                        <Box>
                            <Title order={4}>Send Money</Title>
                            <Group mt="sm">
                                <Select
                                    placeholder="Own / Other Accounts"
                                    data={[{ value: 'own', label: 'Own' }, { value: 'other', label: 'Other' }]}
                                    style={{ width: 180 }}
                                />
                                <Select
                                    placeholder="Select Account"
                                    data={[{ value: 'acc1', label: 'Account 1' }, { value: 'acc2', label: 'Account 2' }]}
                                    style={{ width: 180 }}
                                />
                                <Input placeholder="₹0.00" style={{ width: 100 }} />
                                <Button>Proceed</Button>
                            </Group>
                        </Box>
                    </div>
                    <Flex justify="center" align="center">
                        <Text c="dimmed" size="xs">© 2025 Kangra Central Co- Operative Bank</Text>
                    </Flex>
                </div>
            </Providers>
        );
    }
}